@@ -5,7 +5,7 @@ use warnings;
 our $VERSION='2.00_17';
 
 my %SERIALIZER = (
-    '1.1' => 'SOAP::WSDL::Serializer::SOAP11',
+    '1.1' => 'SOAP::WSDL::Serializer::XSD',
 );
 
 # class method
@@ -138,9 +138,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 325 $
+ $Rev: 329 $
  $LastChangedBy: kutterma $
- $Id: Serializer.pm 325 2007-10-18 10:27:46Z kutterma $
+ $Id: Serializer.pm 329 2007-10-18 19:42:09Z kutterma $
  $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Factory/Serializer.pm $
  
 =cut
