@@ -18,15 +18,38 @@ sub BUILD {
     $self->set_RECURSION(1);
     $self->set_INCLUDE_PATH( exists $arg_ref->{INCLUDE_PATH}
         ? $arg_ref->{INCLUDE_PATH}
-        : File::Spec->rel2abs( dirname __FILE__  ). '/XSD/'
+        : do { 
+            # ignore uninitialized warnings - File::Spec warns about 
+            # uninitialized values, probably because we have no filename
+            local $SIG{__WARN__} = sub {
+                return if ($_[0]=~m{\buninitialized\b});
+                CORE::warn @_;
+            };
+            
+            # makeup path for the OS we're running on
+            my ($volume, $dir, $file) = File::Spec->splitpath( 
+                File::Spec->rel2abs( dirname __FILE__  )
+            );
+            $dir = File::Spec->catdir($dir, $file, 'XSD');
+            # return path put together...
+            my $path = File::Spec->catpath( $volume, $dir );
+            
+            # Fixup path for windows - / works fine, \ does 
+            # not...
+            if ( eval { &Win32::BuildNumber } ) {
+                $path =~s{\\}{/}g;
+            }
+            $path;
+        }
     );
 }
 
 sub generate {
     my $self = shift;
-    $self->generate_typelib();
-    $self->generate_interface();
-    $self->generate_typemap();
+    my $opt = shift;
+    $self->generate_typelib( $opt );
+    $self->generate_interface( $opt );
+    $self->generate_typemap( $opt );
 }
 
 sub generate_typelib {
@@ -54,17 +77,24 @@ sub generate_interface {
             next if not $port->first_address;
             next if not $port->first_address->isa('SOAP::WSDL::SOAP::Address');
 
+            my $port_name = $port->get_name;
+            $port_name =~s{ \A .+\. }{}xms;
             my $output = $arg_ref->{ output } 
                 ? $arg_ref->{ output } 
-                : $self->_generate_filename( $self->get_interface_prefix(), $service->get_name(), $port->get_name ); 
-
+                : $self->_generate_filename( 
+                    $self->get_interface_prefix(), 
+                    $service->get_name(), 
+                    $port_name,
+            ); 
+            print "Creating interface class $output\n";
+            
             $self->_process('Interface.tt', 
             {
                 service => $service,
                 port => $port,
                 NO_POD => $arg_ref->{ NO_POD } ? 1 : 0 ,
-            },
-            $output);
+             },
+            $output, binmode => ':utf8');
         }
     }
 }
@@ -90,6 +120,8 @@ sub generate_typemap {
             my $output = $arg_ref->{ output } 
                 ? $arg_ref->{ output } 
                 : $self->_generate_filename( $self->get_typemap_prefix(), $service->get_name() ); 
+
+            print "Creating typemap class $output\n";
             $self->_process('Typemap.tt', 
             {
                 service => $service,
