@@ -1,10 +1,8 @@
 package SOAP::WSDL::Operation;
 use strict;
 use warnings;
-use Class::Std::Fast::Storable;
-use base qw(SOAP::WSDL::Base);
-
-use version; our $VERSION = qv('2.00.09');
+use Class::Std::Storable;
+use base qw/SOAP::WSDL::Base/;
 
 my %operation_of :ATTR(:name<operation> :default<()>);
 my %input_of :ATTR(:name<input> :default<[]>);
