@@ -1,19 +1,27 @@
 package SOAP::WSDL::Transport::Loopback;
 use strict;
 use warnings;
-use Class::Std::Fast::Storable constructor => 'basic';
+use Class::Std::Storable;
 use SOAP::WSDL::Factory::Transport;
 
-use version; our $VERSION = qv('2.00.09');
+our $VERSION = '2.00_17'; 
 
-# register on loading
 SOAP::WSDL::Factory::Transport->register( http => __PACKAGE__ );
 SOAP::WSDL::Factory::Transport->register( https => __PACKAGE__ );
 
-my %code_of         :ATTR(:name<code>           :default<()>);
-my %status_of       :ATTR(:name<status>         :default<()>);
-my %message_of      :ATTR(:name<message>        :default<()>);
-my %is_success_of   :ATTR(:name<is_success>     :default<()>);
+my %code_of :ATTR(:name<code>           :default<()>);
+my %status_of :ATTR(:name<status>       :default<()>);
+my %message_of :ATTR(:name<message>     :default<()>);
+my %is_success_of :ATTR(:name<is_success> :default<()>);
+
+{
+    no warnings qw(redefine);
+    
+    sub new {
+        my $class = shift;
+        return bless \my ($o), $class;
+    }    
+}
 
 # create methods normally inherited from SOAP::Client
 SUBFACTORY: {
@@ -28,9 +36,6 @@ sub send_receive {
     return $parameters{envelope};
 }
 
-Class::Std::initialize();
-
-
 1;
 
 =head1 NAME
@@ -41,25 +46,25 @@ SOAP::WSDL::Transport::Test - Loopback transport class for SOAP::WSDL
 
  use SOAP::WSDL::Client;
  use SOAP::WSDL::Transport::Loopback;
-
+ 
  my $soap = SOAP::WSDL::Client->new()
  $soap->get_transport->set_base_dir('.');
  $soap->call('method', \%body, \%header);
 
 =head1 DESCRIPTION
 
-SOAP::WSDL::Transport::Loopback is a loopback test transport backend for
-SOAP::WSDL.
+SOAP::WSDL::Transport::Loopback is a loopback test transport backend for 
+SOAP::WSDL. 
 
-When SOAP::WSDL::Transport::Loopback is used as transport backend, the
-request is returned as response. No data ever goes over the wire.
+When SOAP::WSDL::Transport::Loopback is used as transport backend, the 
+request is returned as response. No data ever goes over the wire.                                      
 This is particularly useful for testing SOAP::WSDL plugins and applications.
 
-=head1 LICENSE AND COPYRIGHT
+=head1 LICENSE
 
-Copyright (c) 2007 Martin Kutter. All rights reserved.
+Copyright 2004-2007 Martin Kutter.
 
-This file is part of SOAP-WSDL. You may distribute/modify it under
+This file is part of SOAP-WSDL. You may distribute/modify it under 
 the same terms as perl itself
 
 =head1 AUTHOR
@@ -72,5 +77,5 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
  $LastChangedBy: kutterma $
  $Id: HTTP.pm 218 2007-09-10 16:19:23Z kutterma $
  $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Transport/HTTP.pm $
-
+ 
 =cut
\ No newline at end of file
