@@ -32,18 +32,10 @@ sub serialize {
         , $_[0]->end_tag($_[1]); 
 }
 
-# TODO disallow serializing !
 sub as_bool :BOOLIFY {
     return $value_of { ident $_[0] };
 }
 
-sub _get_handlers {
-    my $parser = $_[1];
-    return {
-        Char => $parser->characters(),
-    }
-}
-
 Class::Std::initialize();   # make :BOOLIFY overloading serializable
 
 
