@@ -1,16 +1,15 @@
+#!/usr/bin/perl
 package SOAP::WSDL::XSD::Typelib::SimpleType;
-use strict; use warnings;
+use strict;
+use Class::Std::Storable;
 use SOAP::WSDL::XSD::Typelib::Builtin;
 
-use version; our $VERSION = qv('2.00.09');
-
 package SOAP::WSDL::XSD::Typelib::SimpleType::restriction;
 use strict;
+use Class::Std::Storable;
 use SOAP::WSDL::XSD::Typelib::Builtin;
 use base qw(SOAP::WSDL::XSD::Typelib::SimpleType);
 
-use version; our $VERSION = qv('2.00.09');
-
 1;
 __END__
 
@@ -33,7 +32,7 @@ modelling XML Schema simpleType definitions.
     #    <restriction base="xsd:string" />
     # </simpleType>
     package MySimpleType;
-    use Class::Std::Fast::Storable constructor => 'none';
+    use Class::Std::Storable;
     # restriction base implemented via inheritance
     use SOAP::WSDL::XSD::Typelib::Builtin;
     use SOAP::WSDL::XSD::Typelib::SimpleType;
@@ -50,7 +49,7 @@ modelling XML Schema simpleType definitions.
     #    <list itemTipe="xsd:string" />
     # </simpleType>
     package MySimpleListType;
-    use Class::Std::Fast::Storable constructor => 'none';
+    use Class::Std::Storable;
     # restriction base implemented via inheritance
     use SOAP::WSDL::XSD::Typelib::Builtin;
     use base ('SOAP::WSDL::XSD::Typelib::SimpleType',
@@ -86,9 +85,9 @@ faint of heart).
 simpleType classes derived via restriction must inherit from these classes in
 exactly this order:
 
- SOAP::WSDL::XSD::Typelib::SimpleType               # you may leave this out
- SOAP::WSDL::XSD::Typelib::SimpleType::restriction  # derive by restriction
- The::Restriction::Base::Class                      # restriction base
+ SOAP::WSDL::XSD::Typelib::SimpleType               # you may leave out this
+ SOAP::WSDL::XSD::Typelib::SimpleType::restriction  # derive by retriction
+ The::Restriction::Base::Class                      # resytriction base
 
 The::Restriction::Base::Class can either be a builtin class (see
 SOAP::WSDL::XSD::Builtin) or another simpleType class.
@@ -105,7 +104,7 @@ complexType definitions.
 
 =item * Thread safety
 
-SOAP::WSDL::XSD::Typelib::SimpleType uses Class::Std::Fast::Storable which uses
+SOAP::WSDL::XSD::Typelib::SimpleType uses Class::Std::Storable which uses
 Class::Std. Class::Std is not thread safe, so
 SOAP::WSDL::XSD::Typelib::SimpleType is neither.
 
@@ -119,23 +118,15 @@ No facets are implemented yet.
 
 =back
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2004-2007 Martin Kutter.
-
-This file is part of SOAP-WSDL. You may distribute/modify it under the same
-terms as perl itself
-
 =head1 AUTHOR
 
-Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
+Replace whitespace by @ in e-mail address.
 
-=head1 REPOSITORY INFORMATION
+ Martin Kutter E<gt>martin.kutter fen-net.deE<lt>
 
- $Rev: 805 $
- $LastChangedBy: kutterma $
- $Id: SimpleType.pm 805 2009-02-23 21:12:24Z kutterma $
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/SimpleType.pm $
+=head1 COPYING
+
+This library is free software, you may distribute/modify it under the
+same terms as perl itself
 
 =cut
-
